@@ -148,12 +148,12 @@ escchr:
 							goto end;
 						for (i = 12, cp = 0; i >= 0; i -= 4) {
 							if ((c = GETNEXT()) == EOF || !isxdigit(c))
-								JSON_INVALID(); /* invalid codepoint */
+								JSON_INVALID(); /* invalid code point */
 							cp |= (hexdigit(c) << i);
 						}
 						/* RFC8259 - 7. Strings - surrogates.
-						 * 0xd800 - 0xdb7f - high surrogates */
-						if (cp >= 0xd800 && cp <= 0xdb7f) {
+						 * 0xd800 - 0xdbff - high surrogates */
+						if (cp >= 0xd800 && cp <= 0xdbff) {
 							if ((c = GETNEXT()) != '\\') {
 								len += codepointtoutf8(cp, &str[len]);
 								goto chr;
@@ -164,7 +164,7 @@ escchr:
 							}
 							for (hi = cp, i = 12, lo = 0; i >= 0; i -= 4) {
 								if ((c = GETNEXT()) == EOF || !isxdigit(c))
-									JSON_INVALID(); /* invalid codepoint */
+									JSON_INVALID(); /* invalid code point */
 								lo |= (hexdigit(c) << i);
 							}
 							/* 0xdc00 - 0xdfff - low surrogates */
